@@ -27,6 +27,13 @@
 
 #include <math.h>
 
+/**
+ * SECTION:goc-widget
+ * @short_description: Widgets.
+ *
+ * #GocWidget implements widgets embedding in the canvas.
+**/
+
 static GocItemClass *widget_parent_class;
 
 enum {
@@ -60,6 +67,16 @@ button_press_cb (G_GNUC_UNUSED GtkWidget *w, GdkEventButton *event, GocWidget *i
 			(event->y + item->y) / item->base.canvas->pixels_per_unit + item->base.canvas->scroll_y1);
 }
 
+static void
+goc_widget_update_bounds (GocItem *item)
+{
+	GocWidget *widget = GOC_WIDGET (item);
+	item->x0 = widget->x;
+	item->y0 = widget->y;
+	item->x1 = widget->x + widget->w;
+	item->y1 = widget->y + widget->h;
+}
+
 static void
 cb_canvas_changed (GocWidget *item, G_GNUC_UNUSED GParamSpec *pspec,
 		   G_GNUC_UNUSED gpointer user)
@@ -94,16 +111,15 @@ goc_widget_notify_scrolled (GocItem *item)
 	if (!parent)
 		return;
 
-	if (!item->cached_bounds)
-		goc_item_update_bounds (GOC_ITEM (item)); /* don't care about const */
+	if (!item->cached_bounds) {
+		goc_widget_update_bounds (GOC_ITEM (item)); /* don't care about const */
+		item->cached_bounds = TRUE;
+	}
 	x0 = item->x0;
 	y0 = item->y0;
 	x1 = item->x1;
 	y1 = item->y1;
-	while (parent) {
-		goc_group_adjust_bounds (parent, &x0, &y0, &x1, &y1);
-		parent = parent->base.parent;
-	}
+	goc_group_adjust_bounds (parent, &x0, &y0, &x1, &y1);
 	x0 = (x0 - item->canvas->scroll_x1) * item->canvas->pixels_per_unit;
 	y0 = (y0 - item->canvas->scroll_y1) * item->canvas->pixels_per_unit;
 	x1 = (x1 - item->canvas->scroll_x1) * item->canvas->pixels_per_unit;
@@ -263,16 +279,6 @@ goc_widget_draw (GocItem const *item, cairo_t *cr)
 					(GdkEventExpose *) goc_canvas_get_cur_event (item->canvas));
 }
 
-static void
-goc_widget_update_bounds (GocItem *item)
-{
-	GocWidget *widget = GOC_WIDGET (item);
-	item->x0 = widget->x;
-	item->y0 = widget->y;
-	item->x1 = widget->x + widget->w;
-	item->y1 = widget->y + widget->h;
-}
-
 static void
 goc_widget_dispose (GObject *object)
 {
@@ -284,6 +290,7 @@ goc_widget_dispose (GObject *object)
 static void
 goc_widget_init (GocWidget *item)
 {
+	item->x = item->y = -G_MAXINT; /* so that it is not visible until the position is set */
 	g_signal_connect (item, "notify::canvas",
 			  G_CALLBACK (cb_canvas_changed),
 			  NULL);
