@@ -64,7 +64,7 @@ static GObjectClass *graph_parent_klass;
 static GogViewClass *gview_parent_klass;
 
 static void apply_theme (GogObject *object, GogTheme const *theme, gboolean force_auto);
-	
+
 static void
 gog_graph_set_property (GObject *obj, guint param_id,
 			GValue const *value, GParamSpec *pspec)
@@ -84,7 +84,7 @@ gog_graph_set_property (GObject *obj, guint param_id,
 				    graph->height);
 		break;
 	case GRAPH_PROP_HEIGHT:
-		gog_graph_set_size (graph, graph->width, 
+		gog_graph_set_size (graph, graph->width,
 				    g_value_get_double (value));
 		break;
 	case GRAPH_PROP_DOCUMENT: {
@@ -169,7 +169,7 @@ cb_theme_changed (GtkComboBox *combo, GogGraph *graph)
 	GSList *theme_names;
 	char const *name;
 	int index = gtk_combo_box_get_active (combo);
-	
+
 	theme_names = gog_theme_registry_get_theme_names ();
 	if (theme_names == NULL)
 		return;
@@ -178,7 +178,7 @@ cb_theme_changed (GtkComboBox *combo, GogGraph *graph)
 	g_slist_free (theme_names);
 	if (name == NULL)
 		return;
-	
+
 	gog_graph_set_theme (graph, gog_theme_registry_lookup (name));
 }
 
@@ -189,9 +189,9 @@ cb_force_theme (GtkButton *button, GogGraph *graph)
 }
 
 static void
-gog_graph_populate_editor (GogObject *gobj, 
-			   GOEditor *editor, 
-			   G_GNUC_UNUSED GogDataAllocator *dalloc, 
+gog_graph_populate_editor (GogObject *gobj,
+			   GOEditor *editor,
+			   G_GNUC_UNUSED GogDataAllocator *dalloc,
 			   GOCmdContext *cc)
 {
 	GogGraph *graph = GOG_GRAPH (gobj);
@@ -206,27 +206,27 @@ gog_graph_populate_editor (GogObject *gobj,
 	(GOG_OBJECT_CLASS(graph_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 
 	theme_names = gog_theme_registry_get_theme_names ();
-	
+
 	if (theme_names != NULL) {
 		GtkWidget *box;
 		GtkWidget *combo;
 		GSList *ptr;
 		char const *graph_theme_name;
 		int count, index = 0;
-		
+
 		graph_theme_name = gog_theme_get_name (graph->theme);
 		combo = go_gtk_builder_get_widget (gui, "theme_combo");
-		gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (combo))));	
-		
+		gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (combo))));
+
 		count = 0;
 		for (ptr = theme_names; ptr != NULL; ptr = ptr->next) {
 			gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _(ptr->data));
-			if (strcmp (ptr->data, graph_theme_name) == 0) 
+			if (strcmp (ptr->data, graph_theme_name) == 0)
 				index = count;
 			count++;
 		}
 		gtk_combo_box_set_active (GTK_COMBO_BOX (combo), index);
-		
+
 		g_signal_connect (G_OBJECT (combo), "changed", G_CALLBACK (cb_theme_changed), graph);
 		g_signal_connect (gtk_builder_get_object (gui, "force_theme_button"), "clicked",
 				  G_CALLBACK (cb_force_theme), graph);
@@ -235,8 +235,8 @@ gog_graph_populate_editor (GogObject *gobj,
 		go_editor_add_page (editor, box, _("Theme"));
 		g_object_unref (gui);
 
-		g_slist_free (theme_names);	
-	}	     
+		g_slist_free (theme_names);
+	}
 
 	go_editor_set_store_page (editor, &graph_pref_page);
 }
@@ -246,9 +246,24 @@ static void
 role_chart_post_add (GogObject *parent, GogObject *chart)
 {
 	GogGraph *graph = GOG_GRAPH (parent);
+	unsigned ypos = 0;
+	if (graph->charts != NULL) {
+		/* find the first row with an unoccupied first column */
+		gboolean *occ = g_alloca (graph->num_rows * sizeof (gboolean));
+		GSList *ptr;
+		int col, row;
+		memset (occ, 0, graph->num_rows * sizeof (gboolean));
+		for (ptr = graph->charts; ptr != NULL; ptr = ptr->next)
+			if (gog_chart_get_position (GOG_CHART (ptr->data), &col, &row, NULL, NULL) && col == 0 && row < (int) graph->num_rows)
+				occ[row] = TRUE;
+		while (ypos < graph->num_rows && occ[ypos])
+			ypos++;
+	}
 	graph->charts = g_slist_prepend (graph->charts, chart);
-	gog_chart_set_position (GOG_CHART (chart),
-		0, GOG_GRAPH (graph)->num_rows, 1, 1);
+	if (!gog_chart_get_position (GOG_CHART (chart), NULL, NULL, NULL, NULL))
+		/* search the first row with column 0 unocupied */
+		gog_chart_set_position (GOG_CHART (chart),
+			0, ypos, 1, 1);
 }
 
 static void
@@ -278,14 +293,14 @@ gog_graph_class_init (GogGraphClass *klass)
 	GogObjectClass *gog_klass = (GogObjectClass *) klass;
 
 	static GogObjectRole const roles[] = {
-		{ N_("Chart"), "GogChart",	0,
-		  GOG_POSITION_SPECIAL|GOG_POSITION_ANY_MANUAL, 
-		  GOG_POSITION_SPECIAL, 
+		{ N_("Chart"), "GogChart",	1,
+		  GOG_POSITION_SPECIAL|GOG_POSITION_ANY_MANUAL,
+		  GOG_POSITION_SPECIAL,
 		  GOG_OBJECT_NAME_BY_ROLE,
 		  NULL, NULL, NULL, role_chart_post_add, role_chart_pre_remove, NULL },
-		{ N_("Title"), "GogLabel",	1,
-		  GOG_POSITION_COMPASS|GOG_POSITION_ANY_MANUAL, 
-		  GOG_POSITION_N|GOG_POSITION_ALIGN_CENTER, 
+		{ N_("Title"), "GogLabel",	0,
+		  GOG_POSITION_COMPASS|GOG_POSITION_ANY_MANUAL,
+		  GOG_POSITION_N|GOG_POSITION_ALIGN_CENTER,
 		  GOG_OBJECT_NAME_BY_ROLE,
 		  NULL, NULL, NULL, NULL, NULL, NULL },
 	};
@@ -301,7 +316,7 @@ gog_graph_class_init (GogGraphClass *klass)
 #ifdef GOFFICE_WITH_GTK
 	gog_klass->populate_editor  = gog_graph_populate_editor;
 #endif
-	
+
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
 	/**
@@ -337,34 +352,34 @@ gog_graph_class_init (GogGraphClass *klass)
 		1, G_TYPE_OBJECT);
 
 	g_object_class_install_property (gobject_klass, GRAPH_PROP_THEME,
-		g_param_spec_object ("theme", 
+		g_param_spec_object ("theme",
 			_("Theme"),
 			_("The theme for elements of the graph"),
-			GOG_TYPE_THEME, 
+			GOG_TYPE_THEME,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_klass, GRAPH_PROP_THEME_NAME,
-		g_param_spec_string ("theme-name", 
+		g_param_spec_string ("theme-name",
 			_("Theme name"),
 			_("The name of the theme for elements of the graph"),
-			"default", 
+			"default",
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GRAPH_PROP_WIDTH,
-		g_param_spec_double ("width-pts", 
+		g_param_spec_double ("width-pts",
 			_("Width"),
 			_("Logical graph width, in points"),
 			0.0, G_MAXDOUBLE, GOG_GRAPH_DEFAULT_WIDTH,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GRAPH_PROP_HEIGHT,
-		g_param_spec_double ("height-pts", 
+		g_param_spec_double ("height-pts",
 			_("Height"),
 			_("Logical graph heigth, in points"),
 			0.0, G_MAXDOUBLE, GOG_GRAPH_DEFAULT_HEIGHT,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GRAPH_PROP_DOCUMENT,
-		g_param_spec_object ("document", 
+		g_param_spec_object ("document",
 			_("Document"),
 			_("the document for this graph"),
-			GO_TYPE_DOC, 
+			GO_TYPE_DOC,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 }
 
@@ -419,17 +434,19 @@ gog_graph_validate_chart_layout (GogGraph *graph)
 	max_col = max_row = 0;
 	for (ptr = graph->charts ; ptr != NULL ; ptr = ptr->next) {
 		chart = ptr->data;
-		if (max_col < (chart->x + chart->cols))
-			max_col = (chart->x + chart->cols);
-		if (max_row < (chart->y + chart->rows))
-			max_row = (chart->y + chart->rows);
+		chart->x_pos_actual = chart->x_pos;
+		chart->y_pos_actual = chart->y_pos;
+		if (max_col < (chart->x_pos_actual + chart->cols))
+			max_col = (chart->x_pos_actual + chart->cols);
+		if (max_row < (chart->y_pos_actual + chart->rows))
+			max_row = (chart->y_pos_actual + chart->rows);
 	}
 
 	/* 2) see if we need to contract any cols */
 	for (i = 0 ; i < max_col ; ) {
 		for (ptr = graph->charts ; ptr != NULL ; ptr = ptr->next) {
 			chart = ptr->data;
-			if (chart->x <= i && i < (chart->x + chart->cols))
+			if (chart->x_pos_actual <= i && i < (chart->x_pos_actual + chart->cols))
 				break;
 		}
 		if (ptr == NULL) {
@@ -437,18 +454,18 @@ gog_graph_validate_chart_layout (GogGraph *graph)
 			max_col--;
 			for (ptr = graph->charts ; ptr != NULL ; ptr = ptr->next) {
 				chart = ptr->data;
-				if (chart->x > i)
-					(chart->x)--;
+				if (chart->x_pos_actual > i)
+					(chart->x_pos_actual)--;
 			}
 		} else
-			i = chart->x + chart->cols;
+			i = chart->x_pos_actual + chart->cols;
 	}
 
 	/* 3) see if we need to contract any rows */
 	for (i = 0 ; i < max_row ; ) {
 		for (ptr = graph->charts ; ptr != NULL ; ptr = ptr->next) {
 			chart = ptr->data;
-			if (chart->y <= i && i < (chart->y + chart->rows))
+			if (chart->y_pos_actual <= i && i < (chart->y_pos_actual + chart->rows))
 				break;
 		}
 		if (ptr == NULL) {
@@ -456,11 +473,11 @@ gog_graph_validate_chart_layout (GogGraph *graph)
 			max_row--;
 			for (ptr = graph->charts ; ptr != NULL ; ptr = ptr->next) {
 				chart = ptr->data;
-				if (chart->y > i)
-					(chart->y)--;
+				if (chart->y_pos_actual > i)
+					(chart->y_pos_actual)--;
 			}
 		} else
-			i = chart->y + chart->rows;
+			i = chart->y_pos_actual + chart->rows;
 	}
 	changed |= (graph->num_cols != max_col || graph->num_rows != max_row);
 
@@ -513,14 +530,14 @@ apply_theme (GogObject *object, GogTheme const *theme, gboolean force_auto)
 	GSList *ptr;
 
 	for (ptr = object->children; ptr !=  NULL; ptr = ptr->next)
-		apply_theme (ptr->data, theme, force_auto);		
+		apply_theme (ptr->data, theme, force_auto);
 
 	if (GO_IS_STYLED_OBJECT (object)) {
 		GOStyledObject *styled_object = (GOStyledObject *) object;
 		GOStyle *style;
 
 		style = go_styled_object_get_style (styled_object);
-		if (force_auto) 
+		if (force_auto)
 			/* FIXME: Some style settings are not themed yet,
 			 * such as font or fill type. */
 			go_style_force_auto (style);
@@ -538,7 +555,7 @@ gog_graph_set_theme (GogGraph *graph, GogTheme *theme)
 
 	graph->theme = theme;
 
-	apply_theme (GOG_OBJECT (graph), graph->theme, FALSE);	
+	apply_theme (GOG_OBJECT (graph), graph->theme, FALSE);
 }
 
 /**
@@ -581,7 +598,7 @@ gog_graph_ref_data (GogGraph *graph, GOData *dat)
 	if (res == NULL) {
 
 		/* is there something like it already */
-		GSList *existing = graph->data; 
+		GSList *existing = graph->data;
 		for (; existing != NULL ; existing = existing->next)
 			if (go_data_eq (dat, existing->data))
 				break;
@@ -797,7 +814,6 @@ gog_graph_view_size_allocate (GogView *view, GogViewAllocation const *bbox)
 {
 	GSList *ptr;
 	double h, w;
-	unsigned x, y, rows, cols;
 	GogView *child;
 	GogGraph *graph = GOG_GRAPH (view->model);
 	GogViewAllocation tmp, res = *bbox;
@@ -814,12 +830,11 @@ gog_graph_view_size_allocate (GogView *view, GogViewAllocation const *bbox)
 	for (ptr = view->children; ptr != NULL ; ptr = ptr->next) {
 		child = ptr->data;
 		if (GOG_POSITION_IS_SPECIAL (child->model->position)) {
-			gog_chart_get_position (GOG_CHART (child->model),
-				&x, &y, &cols, &rows);
-			tmp.x = x * w + res.x;
-			tmp.y = y * h + res.y;
-			tmp.w = cols * w;
-			tmp.h = rows * h;
+			GogChart *chart = GOG_CHART (child->model);
+			tmp.x = chart->x_pos_actual * w + res.x;
+			tmp.y = chart->y_pos_actual * h + res.y;
+			tmp.w = chart->cols * w;
+			tmp.h = chart->rows * h;
 			gog_view_size_allocate (child, &tmp);
 		}
 	}
@@ -829,9 +844,26 @@ static void
 gog_graph_view_render  (GogView *view, GogViewAllocation const *bbox)
 {
 	GogGraphView *gview = GOG_GRAPH_VIEW (view);
+	GSList *ptr;
+	GogView *child_view;
 
 	gview_parent_klass->render (view, bbox);
 
+	/* render everything except labels */
+	for (ptr = view->children ; ptr != NULL ; ptr = ptr->next) {
+		child_view = ptr->data;
+		if (GOG_IS_LABEL (child_view->model))
+			continue;
+		gog_view_render	(ptr->data, bbox);
+	}
+	/* render labels */
+	for (ptr = view->children ; ptr != NULL ; ptr = ptr->next) {
+		child_view = ptr->data;
+		if (!GOG_IS_LABEL (child_view->model))
+			continue;
+		gog_view_render	(ptr->data, bbox);
+	}
+
 	if (gview->selected_view != NULL)
 		gog_view_render_toolkit (gview->selected_view);
 }
@@ -845,7 +877,7 @@ gog_graph_view_finalize (GObject *obj)
 		gog_tool_action_free (gview->action);
 		gview->action = NULL;
 	}
-	
+
 	(G_OBJECT_CLASS (gview_parent_klass)->finalize) (obj);
 }
 
@@ -854,6 +886,7 @@ gog_graph_view_class_init (GogGraphViewClass *gview_klass)
 {
 	GogViewClass *view_klass    = (GogViewClass *) gview_klass;
 	GObjectClass *gobject_klass = (GObjectClass *) view_klass;
+	GogOutlinedViewClass *oview_klass = (GogOutlinedViewClass *) gview_klass;
 
 	gview_parent_klass = g_type_class_peek_parent (gview_klass);
 	gobject_klass->set_property = gog_graph_view_set_property;
@@ -862,14 +895,15 @@ gog_graph_view_class_init (GogGraphViewClass *gview_klass)
 	view_klass->render	    = gog_graph_view_render;
 	view_klass->size_allocate   = gog_graph_view_size_allocate;
 	view_klass->clip	    = TRUE;
+	oview_klass->call_parent_render = FALSE;
 
 	g_object_class_install_property (gobject_klass, GRAPH_VIEW_PROP_RENDERER,
-		g_param_spec_object ("renderer", 
+		g_param_spec_object ("renderer",
 			_("Renderer"),
 			_("the renderer for this view"),
-			GOG_TYPE_RENDERER, 
+			GOG_TYPE_RENDERER,
 			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
-	
+
 	gog_graph_view_signals [GRAPH_VIEW_SELECTION_CHANGED] = g_signal_new ("selection-changed",
 		G_TYPE_FROM_CLASS (gview_klass),
 		G_SIGNAL_RUN_LAST,
@@ -901,7 +935,7 @@ update_cursor (GogGraphView *view, GogTool *tool, GdkWindow *window)
 {
 	GdkCursor *cursor;
 	GdkCursorType cursor_type;
-	
+
 	cursor_type = tool != NULL ? tool->cursor_type : GDK_LEFT_PTR;
 	if (cursor_type != view->cursor_type) {
 		view->cursor_type = cursor_type;
@@ -916,11 +950,11 @@ update_cursor (GogGraphView *view, GogTool *tool, GdkWindow *window)
 static void
 update_action (GogGraphView *view, GogTool *tool, double x, double y)
 {
-	if (view->action != NULL) { 
+	if (view->action != NULL) {
 		gog_tool_action_free (view->action);
 		view->action = NULL;
 	}
-	
+
 	if (tool != NULL)
 		view->action = gog_tool_action_new (view->selected_view, tool, x, y);
 }
@@ -938,7 +972,7 @@ update_action (GogGraphView *view, GogTool *tool, double x, double y)
  * Handle events.
  **/
 void
-gog_graph_view_handle_event (GogGraphView *view, GdkEvent *event, 
+gog_graph_view_handle_event (GogGraphView *view, GdkEvent *event,
 			     double x_offset, double y_offset)
 {
 	GogObject *old_object = view->selected_object;
@@ -946,25 +980,25 @@ gog_graph_view_handle_event (GogGraphView *view, GdkEvent *event,
 	GdkWindow *window = event->any.window;
 	double x, y;
 	int x_int, y_int;
-	
+
 	x = event->button.x - x_offset;
 	y = event->button.y - y_offset;
 
 	switch (event->type) {
 		case GDK_2BUTTON_PRESS:
-			if (view->action != NULL) 
+			if (view->action != NULL)
 				gog_tool_action_double_click (view->action);
 			break;
-		case GDK_BUTTON_PRESS: 
+		case GDK_BUTTON_PRESS:
 			if (view->selected_view != NULL)
 				tool = gog_view_get_tool_at_point (view->selected_view, x, y,
 								   &view->selected_object);
-			if (tool == NULL) 
-				view->selected_view = gog_view_get_view_at_point (GOG_VIEW (view), x, y, 
-										  &view->selected_object, 
+			if (tool == NULL)
+				view->selected_view = gog_view_get_view_at_point (GOG_VIEW (view), x, y,
+										  &view->selected_object,
 										  &tool);
 			if (old_object != view->selected_object) {
-				g_signal_emit (G_OBJECT (view), 
+				g_signal_emit (G_OBJECT (view),
 					       gog_graph_view_signals [GRAPH_VIEW_SELECTION_CHANGED],
 					       0, view->selected_object);
 				gog_view_queue_redraw (GOG_VIEW (view));
@@ -972,7 +1006,7 @@ gog_graph_view_handle_event (GogGraphView *view, GdkEvent *event,
 			update_action (view, tool, x, y);
 			update_cursor (view, tool, window);
 			break;
-		case GDK_MOTION_NOTIFY: 
+		case GDK_MOTION_NOTIFY:
 			if (event->motion.is_hint) {
 				gdk_window_get_pointer (window, &x_int, &y_int, NULL);
 				x = x_int - x_offset;
@@ -1019,8 +1053,8 @@ gog_graph_view_get_selection (GogGraphView *gview)
  * gog_graph_view_set_selection
  * @gview : #GogGraphView
  * @gobj : new selected object
- * 
- * Sets @gobj as current selection. If @gobj is different from previously 
+ *
+ * Sets @gobj as current selection. If @gobj is different from previously
  * selected object, a selection-changed signal is emitted.
  **/
 void
@@ -1043,8 +1077,8 @@ gog_graph_view_set_selection (GogGraphView *gview, GogObject *gobj)
 	}
 
 	gog_view_queue_redraw (GOG_VIEW (gview));
-	g_signal_emit (G_OBJECT (gview), 
-		       gog_graph_view_signals [GRAPH_VIEW_SELECTION_CHANGED], 
+	g_signal_emit (G_OBJECT (gview),
+		       gog_graph_view_signals [GRAPH_VIEW_SELECTION_CHANGED],
 		       0, gobj);
 }
 
@@ -1091,7 +1125,7 @@ gog_graph_get_supported_image_formats (void)
  * @y_dpi: y resolution of exported graph
  *
  * Exports an image of @graph in given @format, writing results in a #GsfOutput stream.
- * If export format type is a bitmap one, it computes image size with x_dpi, y_dpi and 
+ * If export format type is a bitmap one, it computes image size with x_dpi, y_dpi and
  * @graph size (see @gog_graph_get_size()).
  *
  * returns: %TRUE if export succeed.
